@@ -1,7 +1,7 @@
 archi <- function(dist,alpha)
 {
     if (class(dist) != 'dist') {
-        stop("You must pass an oject of class dist as the first argument")
+        stop("You must pass an object of class dist as the first argument")
     }
     y <- as.matrix(dist)
     clustering <- rep(0,nrow(y))
@@ -13,5 +13,7 @@ archi <- function(dist,alpha)
         PACKAGE='optpart')
     out <- list(clustering=tmp$clustering)
     class(out) <- 'clustering'
+    attr(out,'call') <- match.call()
+    attr(out,'timestamp') <- date()
     out 
 }
