@@ -5,12 +5,19 @@ optpart <- function(x, dist, maxitr=100, mininc=0.001, maxdmu=1)
 
 opt.core <- function (dist, clustering, mininc, maxdmu, maxitr)
 {
+    if (!inherits(dist,'dist'))
+        stop("The first argument must be an object of class 'dist'") 
+    clustering <- as.numeric(clustify(clustering))
     numclu <- length(table(clustering))
     simptp <- 1 - as.matrix(dist)
     simptc <- matrix(0, nrow = nrow(simptp), ncol = numclu)
     simctc <- matrix(0, nrow = numclu, ncol = numclu)
     cardin <- matrix(0, nrow = numclu)
     musubx <- matrix(0, nrow = nrow(simptp), ncol = numclu)
+    dratio <- matrix(0, nrow = numclu, ncol = numclu)
+    maxdif <- matrix(0, nrow = numclu, ncol = numclu)
+    dltamu <- matrix(0, nrow = numclu, ncol = numclu)
+    pltdif <- matrix(0, nrow = numclu, ncol = numclu)
     final <- musubx
     simrat <- rep(0, maxitr)
     numitr <- 0
@@ -19,14 +26,17 @@ opt.core <- function (dist, clustering, mininc, maxdmu, maxitr)
         as.double(cardin), as.integer(nrow(simptp)), as.integer(numclu),
         musubx = as.double(musubx), as.double(final), clustering = as.integer(clustering),
         as.double(maxdmu), as.integer(maxitr), numitr = as.integer(numitr),
+        as.double(dratio),as.double(maxdif),as.double(dltamu),as.integer(pltdif),
         PACKAGE = "optpart")
     out <- list(ptc = matrix(data = tmp$simptc, ncol = numclu),
         ctc = matrix(data = tmp$simctc, ncol = numclu), musubx = matrix(tmp$musubx,
             nrow = nrow(simptp)), clustering = as.numeric(factor(tmp$clustering)),
         ratio = tmp$simrat[1:tmp$numitr], numitr = tmp$numitr,
         names = attr(dist, "Labels"))
+    names(out$clustering) <- attr(dist, "Labels")
     attr(out, "class") <- c("partana", "clustering")
     attr(out, "call") <- call
+    attr(out,'timestamp') <- date()
     out
 }
 
@@ -53,14 +63,17 @@ optpart.default <- function(x, dist, maxitr = 100, mininc = 0.001, maxdmu = 1)
  
     attr(out,"class") <- c("partana", "clustering")
     attr(out,'call') <- match.call()
+    attr(out,'timestamp') <- date()
     out
 }
 
 
 optpart.stride <- function(x,dist,maxitr=100,mininc=0.001,maxdmu=1.0)
 {
-    if (class(x) != 'stride')
-        stop('You must pass an object of class stride')
+    if (!inherits(x,'stride'))
+        stop("The first argument must be an object of class 'stride'")
+    if (!inherits(dist,'dist'))
+        stop("The second argument must be an object of class 'dist'")
     res <- matrix(NA,nrow=nrow(x$clustering),ncol=ncol(x$clustering))
     for (i in 1:ncol(x$clustering)) {
         tmp <- opt.core(dist,x$clustering[,i],maxitr=maxitr,mininc=0.001,maxdmu=1.0)
@@ -71,6 +84,8 @@ optpart.stride <- function(x,dist,maxitr=100,mininc=0.001,maxdmu=1.0)
     row.names(out) <- row.names(x$clustering)
     out <- list(clustering=out,seq=x$seq)
     class(out) <- 'stride'
+    attr(out,'call') <- match.call()
+    attr(out,'timestamp') <- date()
     out
 }
 
@@ -91,7 +106,7 @@ bestopt <- function (dist, numclu, numrep, maxitr=100)
         }
     }
     cat("Ratios for respective optparts \n")
-    print(format(ratios, digits = 4))
+    print(as.numeric(format(ratios, digits = 4)))
     cat(paste("\nChoosing # ", itr, " ratio = ", format(best,
         digits = 4), "\n"))
     invisible(result)
