@@ -5,15 +5,16 @@ partition <- function(x, dist, ...)
 
 partition.default <- function (x, dist, ...)
 {
-    if (class(dist) != 'dist') {
-        stop("You must supply an object of class dist as the second argument")
+    if (!inherits(dist,'dist')) {
+        stop("The second argument must be an object of class 'dist'")
     }
     x <- as.numeric(clustify(x))
     out <- list()
-    attr(out,"call") <- match.call()
     out$diss <- dist
     out$clustering <- x
     out$silinfo <- silhouette(x,dist)
     attr(out,'class') <- 'partition'
+    attr(out,"call") <- match.call()
+    attr(out,'timestamp') <- date()
     return(out)
 }
